# 评论区

<img src="/imgs/comment.svg" width="100" height="100"/>

评论区接口分为**查询**与**操作**两大类

- [查询类](list.md)
- [操作类](action.md)

## 已知的评论区类型代码总览

| 代码 | 评论区类型              | oid的意义  |
| ---- | ----------------------- | ---------- |
| 1    | 视频稿件                | 稿件avID   |
| 2    | 话题                    | 话题ID     |
| 4    | 活动                    | 活动ID     |
| 5    | 小视频                  | 小视频ID   |
| 6    | 小黑屋封禁信息          | 封禁公示ID |
| 7    | 公告信息                | 公告ID     |
| 8    | 直播活动                | 直播间ID   |
| 9    | 活动稿件                |            |
| 10   | 直播公告                |            |
| 11   | 相簿（图片动态）        | 相簿ID     |
| 12   | 专栏                    | 专栏cvID   |
| 13   | 票务                    |            |
| 14   | 音频                    | 音频auID   |
| 15   | 风纪委员会              | 众裁项目ID |
| 16   | 点评                    |            |
| 17   | 动态（纯文字动态&分享） | 动态ID     |
| 18   | 播单                    |            |
| 19   | 音乐播单                |            |
| 20   | 漫画                    |            |
| 21   | 漫画                    |            |
| 22   | 漫画                    | 漫画mcID   |
| 33   | 课程                    | 课程epID   |

## 评论条目对象

| 字段        | 类型                            | 内容             | 备注                                                         |
| ----------- | ------------------------------- | ---------------- | ------------------------------------------------------------ |
| rpid        | num                             | 评论rpID         |                                                              |
| oid         | num                             | 目标评论区rpID   |                                                              |
| type        | num                             | 评论区类型代码   | **类型代码见上表**                                           |
| mid         | num                             | 评论发送者UID    |                                                              |
| root        | num                             | 根评论rpID       | 若为一级评论则为0<br />大于一级评论则为根评论ID              |
| parent      | num                             | 回复父评论rpID   | 若为一级评论则为0<br />若为二级评论则为根评论rpID<br />大于二级评论为上一级评论rpID |
| dialog      | num                             | 回复对方rpID     | 若为一级评论则为0<br />若为二级评论则为该评论rpID<br />大于二级评论为上一级评论rpID |
| count       | num                             | 评论回复条数     |                                                              |
| rcount      | num                             | 评论回复条数     |                                                              |
| floor       | num                             | 评论楼层号       | **重要：若不支持楼层则无此项**                               |
| state       | num                             | 0                | **作用尚不明确**                                             |
| fansgrade   | num                             | 是否具有粉丝标签 | 0：无<br />1：有                                             |
| attr        | num                             | ？？？           | **作用尚不明确**                                             |
| ctime       | num                             | 评论发送时间     | 时间戳                                                       |
| rpid_str    | str                             | 评论rpID         | 字串格式                                                     |
| root_str    | str                             | 根评论rpID       | 字串格式                                                     |
| parent_str  | str                             | 回复父评论rpID   | 字串格式                                                     |
| like        | num                             | 评论获赞数       |                                                              |
| action      | num                             | 当前用户操作状态 | 需要登录(SESSDATA) <br />否则恒为0<br />0：无<br />1：已点赞<br />2：已点踩 |
| member      | obj                             | 评论发送者信息   |                                                              |
| content     | obj                             | 评论信息         |                                                              |
| replies     | 无效时：null<br />有效时：array | 评论回复条目预览 | **仅嵌套一层**<br />否则为null                               |
| assist      | num                             |                  | **作用尚不明确**                                             |
| folder      | obj                             | ？？？           |                                                              |
| up_action   | obj                             | 评论UP主操作信息 |                                                              |
| show_follow | bool                            | false            | **作用尚不明确**                                             |

`评论条目`中的`member`对象：

| 字段            | 类型                          | 内容                   | 备注                                                         |
| --------------- | ----------------------------- | ---------------------- | ------------------------------------------------------------ |
| mid             | str                           | 发送者UID              |                                                              |
| uname           | str                           | 发送者昵称             |                                                              |
| sex             | str                           | 发送者性别             | 男 女 保密                                                   |
| sign            | str                           | 发送者签名             |                                                              |
| avatar          | str                           | 发送者头像             |                                                              |
| rank            | str                           | 10000                  | **作用尚不明确**                                             |
| DisplayRank     | str                           | 0                      | **作用尚不明确**                                             |
| level_info      | obj                           | 发送者等级             |                                                              |
| pendant         | obj                           | 发送者头像框信息       |                                                              |
| nameplate       | obj                           | 发送者勋章信息         |                                                              |
| official_verify | obj                           | 发送者认证信息         |                                                              |
| vip             | obj                           | 发送者会员信息         |                                                              |
| fans_detail     | 无效时：null<br />有效时：obj | 发送者粉丝标签         |                                                              |
| following       | num                           | 是否关注该用户         | 需要登录(SESSDATA) <br />否则恒为0<br />0：未关注<br />1：已关注 |
| is_followed     | num                           | 是否被该用户关注       | 需要登录(SESSDATA) <br />否则恒为0<br />0：未关注<br />1：已关注 |
| user_sailing    | obj                           | 发送者评论条目装扮信息 |                                                              |

`member`中的`level_info`对象：

| 字段          | 类型 | 内容     | 备注             |
| ------------- | ---- | -------- | ---------------- |
| current_level | num  | 用户等级 |                  |
| current_min   | num  | 0        | **作用尚不明确** |
| current_exp   | num  | 0        | **作用尚不明确** |
| next_exp      | num  | 0        | **作用尚不明确** |

`member`中的`pendant`对象：

| 字段          | 类型 | 内容          | 备注                 |
| ------------- | ---- | ------------- | -------------------- |
| pid           | num  | 头像框id      | **详细说明有待补充** |
| name          | str  | 头像框名称    |                      |
| image         | str  | 头像框图片url |                      |
| expire        | num  | 0             | **作用尚不明确**     |
| image_enhance | str  | 头像框图片url |                      |

`member`中的`nameplate`对象：

| 字段        | 类型 | 内容             | 备注                 |
| ----------- | ---- | ---------------- | -------------------- |
| nid         | num  | 勋章id           | **详细说明有待补充** |
| name        | str  | 勋章名称         |                      |
| image       | str  | 挂件图片url 正常 |                      |
| image_small | str  | 勋章图片url 小   |                      |
| level       | str  | 勋章等级         |                      |
| condition   | str  | 勋章条件         |                      |

`member`中的`official_verify`对象：

| 字段 | 类型 | 内容     | 备注                |
| ---- | ---- | -------- | ------------------- |
| type | num  | 是否认证 | -1：无<br />0：认证 |
| desc | str  | 认证信息 | 无为空              |

`member`中的`vip`对象：

| 字段          | 类型 | 内容           | 备注                                |
| ------------- | ---- | -------------- | ----------------------------------- |
| vipType       | num  | 大会员类型     | 0：无<br />1：月会员<br />2：年会员 |
| vipDueDate    | num  | 大会员到期时间 | 毫秒 时间戳                         |
| dueRemark     | str  | 空             | **作用尚不明确**                    |
| accessStatus  | num  | 0              | **作用尚不明确**                    |
| vipStatus     | num  | 大会员状态     | 0：无<br />1：有                    |
| vipStatusWarn | str  | 空             | **作用尚不明确**                    |
| theme_type    | num  | 0              | **作用尚不明确**                    |
| label         | obj  | ？？？         |                                     |

`vip`中的`label`对象:

| 字段        | 类型 | 内容         | 备注             |
| ----------- | ---- | ------------ | ---------------- |
| path        | str  | 空           | **作用尚不明确** |
| text        | str  | 会员类型信息 |                  |
| label_theme | str  | 会员类型     |                  |

`member`中的`fans_detail`对象:

| 字段          | 类型 | 内容         | 备注                 |
| ------------- | ---- | ------------ | -------------------- |
| uid           | num  | 用户UID      |                      |
| medal_id      | num  | 粉丝标签ID   | **详细说明有待补充** |
| medal_name    | str  | 粉丝标签名   |                      |
| score         | num  | 0            | **作用尚不明确**     |
| level         | num  | 当前标签等级 |                      |
| intimacy      | num  | 0            | **作用尚不明确**     |
| master_status | num  | 1            | **作用尚不明确**     |
| is_receive    | num  | 1            | **作用尚不明确**     |

`member`中的`user_sailing`对象：

| 字段              | 类型                          | 内容         | 备注             |
| ----------------- | ----------------------------- | ------------ | ---------------- |
| pendant           | 无效时：null<br />有效时：obj | 头像框信息   |                  |
| cardbg            | 无效时：null<br />有效时：obj | 评论条目装扮 |                  |
| cardbg_with_focus | null                          | -            | **作用尚不明确** |

`user_sailing`中的`pendant`对象：

| 字段     | 类型 | 内容          | 备注                                  |
| -------- | ---- | ------------- | ------------------------------------- |
| id       | num  | 头像框ID      |                                       |
| name     | str  | 头像框名称    |                                       |
| image    | str  | 头像框图片url |                                       |
| jump_url | str  | 空            |                                       |
| type     | str  | 装扮类型      | suit：一般装扮<br />vip_suit：vip装扮 |

`user_sailing`中的`cardbg`对象：

| 字段     | 类型 | 内容                    | 备注                                  |
| -------- | ---- | ----------------------- | ------------------------------------- |
| id       | num  | 评论条目装扮ID          |                                       |
| name     | str  | 评论条目装扮名称        |                                       |
| image    | str  | 评论条目装扮图片url     |                                       |
| jump_url | str  | 评论条目装扮商城页面url |                                       |
| fan      | obj  | 粉丝专属信息            |                                       |
| type     | str  | 装扮类型                | suit：一般装扮<br />vip_suit：vip装扮 |

`cardbg`中的`fan`对象：

| 字段     | 类型 | 内容               | 备注             |
| -------- | ---- | ------------------ | ---------------- |
| is_fan   | num  | 是否为粉丝专属装扮 | 0：否<br />1：是 |
| number   | num  | 粉丝专属编号       |                  |
| color    | str  | 数字颜色           | 颜色码           |
| name     | str  | 装扮名称           |                  |
| num_desc | str  | 粉丝专属编号       | 字串格式         |

`评论条目`中的`content`对象：

| 字段     | 类型  | 内容                 | 备注                                                         |
| -------- | ----- | -------------------- | ------------------------------------------------------------ |
| message  | str   | 评论内容             | **重要**                                                     |
| plat     | num   | 评论发送平台         | 1：web端<br />2：安卓客户端<br />3：ios客户端<br />4：wp客户端 |
| device   | str   | 评论发送平台设备     |                                                              |
| members  | array | 评论中at到的用户信息 |                                                              |
| emote    | obj   | 表情转义符信息       | 评论内容无表情则无此项                                       |
| jump_url | obj   | 空                   | **作用尚不明确**                                             |
| max_line | num   | 6                    | **作用尚不明确**                                             |

`content`中的`members`数组：

| 项   | 类型 | 内容            | 备注                             |
| ---- | ---- | --------------- | -------------------------------- |
| 0    | obj  | at到的用户1     | 基本同`评论条目`中的`member`对象 |
| n    | obj  | at到的用户(n+1) | 项数为at到的不同的用户数         |
| ……   | obj  | ……              | ……                               |

`content`中的`emote`对象：

| 字段         | 类型 | 内容            | 备注     |
| ------------ | ---- | --------------- | -------- |
| {表情转义符} | obj  | 表情转义符信息1 |          |
| ……           | obj  | 表情转义符信息n | 向下扩展 |

`emote`中的`{表情转义符}`对象：

| 字段       | 类型 | 内容         | 备注                                                     |
| ---------- | ---- | ------------ | -------------------------------------------------------- |
| id         | num  | 表情ID       |                                                          |
| package_id | num  | 表情包ID     |                                                          |
| state      | num  | 0            |                                                          |
| type       | num  | 表情类型     | 1：免费<br />2：会员专属<br />3：购买所得<br />4：颜文字 |
| attr       | num  | 0            | **作用尚不明确**                                         |
| text       | str  | 表情转义符   |                                                          |
| url        | str  | 表情图片url  |                                                          |
| meta       | obj  | 属性信息     |                                                          |
| mtime      | num  | 表情创建时间 | 时间戳                                                   |

`{表情转义符}`中的`meta`对象：

| 字段  | 类型 | 内容         | 备注             |
| ----- | ---- | ------------ | ---------------- |
| size  | num  | 表情尺寸信息 | 1：小<br />2：大 |
| alias | str  | 简写名       | 无则无此项       |

`评论条目`中的`replies`数组：

| 项   | 类型 | 内容      | 备注                                                         |
| ---- | ---- | --------- | ------------------------------------------------------------ |
| 0    | obj  | 回复条目1 | **为本对象的递归嵌套**<br />**仅嵌套一层**<br />按照热度顺序排列 |
| 1    | obj  | 回复条目2 |                                                              |
| 2    | obj  | 回复条目3 | 最后一项                                                     |

`评论条目`中的`folder`对象：

| 字段       | 类型 | 内容   | 备注             |
| ---------- | ---- | ------ | ---------------- |
| has_folded | bool | false  | **作用尚不明确** |
| is_folded  | bool | false  | **作用尚不明确** |
| rule       | str  | ？？？ | **作用尚不明确** |

`评论条目`中的`up_action`对象：

| 字段  | 类型 | 内容             | 备注                    |
| ----- | ---- | ---------------- | ----------------------- |
| like  | bool | 是否UP主觉得很赞 | false：否<br />true：是 |
| reply | bool | 是否被UP主回复   | false：否<br />true：是 |